From bb3a391c235603f7ff124a117316d5f517e8ba9e Mon Sep 17 00:00:00 2001
From: Sai Krishna Metpalli <310911@NTTDATA.COM>
Date: Wed, 26 Jun 2024 13:27:55 -0700
Subject: [PATCH 01/13] 2.2.9 Updated the version
---
gitops/charts/traffic-court-dev-values.yaml | 18 +++++++++---------
gitops/charts/traffic-court-prod-values.yaml | 18 +++++++++---------
gitops/charts/traffic-court-test-values.yaml | 18 +++++++++---------
3 files changed, 27 insertions(+), 27 deletions(-)
diff --git a/gitops/charts/traffic-court-dev-values.yaml b/gitops/charts/traffic-court-dev-values.yaml
index 9aca6c71d..e29ce6fbb 100644
--- a/gitops/charts/traffic-court-dev-values.yaml
+++ b/gitops/charts/traffic-court-dev-values.yaml
@@ -7,14 +7,14 @@ global:
arc-dispute-api:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"Swagger__Enabled": "true"
citizen-api:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"FormRecognizer__ApiVersion": "2022-08-31"
@@ -30,7 +30,7 @@ citizen-api:
citizen-web:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
route:
# https://dev.justice.gov.bc.ca
@@ -39,7 +39,7 @@ citizen-web:
{
"production": false,
"environment": "Dev",
- "version": "2.1.10",
+ "version": "2.2.9",
"useMockServices": false,
"apiBaseUrl": "/api",
"understandYourTicketLink": "https://understandmyticket.gov.bc.ca/",
@@ -193,7 +193,7 @@ citizen-web:
oracle-data-api:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"JAVA_OPTS": "-Dlogging.level.ca.bc.gov.open.jag.tco.oracledataapi=DEBUG"
@@ -208,7 +208,7 @@ oracle-data-api:
staff-api:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"Jwt__Audience": "staff-api"
@@ -222,7 +222,7 @@ staff-api:
staff-web:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
route:
# https://dev.jag.gov.bc.ca
@@ -241,7 +241,7 @@ staff-web:
{
"production": false,
"environment": "Dev",
- "version": "2.1.10",
+ "version": "2.2.9",
"useMockServices": false,
"apiBaseUrl": "/api",
"features": {
@@ -251,7 +251,7 @@ staff-web:
workflow-service:
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"EmailConfiguration__Sender": "DoNotReply@gov.bc.ca"
diff --git a/gitops/charts/traffic-court-prod-values.yaml b/gitops/charts/traffic-court-prod-values.yaml
index cde7b8b24..3051369e0 100644
--- a/gitops/charts/traffic-court-prod-values.yaml
+++ b/gitops/charts/traffic-court-prod-values.yaml
@@ -10,7 +10,7 @@ arc-dispute-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"Swagger__Enabled": "false"
@@ -20,7 +20,7 @@ citizen-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"FormRecognizer__ApiVersion": "2022-08-31"
@@ -39,13 +39,13 @@ citizen-web:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
appConfig: |
{
"production": true,
"environment": "prod",
- "version": "2.1.10",
+ "version": "2.2.9",
"useMockServices": false,
"apiBaseUrl": "/api",
"understandYourTicketLink": "https://understandmyticket.gov.bc.ca/",
@@ -221,7 +221,7 @@ oracle-data-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"JAVA_OPTS": ""
@@ -238,7 +238,7 @@ staff-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"Jwt__Audience": "staff-api"
@@ -256,7 +256,7 @@ staff-web:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
route:
# https://test.jag.gov.bc.ca
@@ -275,7 +275,7 @@ staff-web:
{
"production": true,
"environment": "prod",
- "version": "2.1.10",
+ "version": "2.2.9",
"useMockServices": false,
"apiBaseUrl": "/api",
"features": {
@@ -288,7 +288,7 @@ workflow-service:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"EmailConfiguration__Sender": "DoNotReply@gov.bc.ca"
diff --git a/gitops/charts/traffic-court-test-values.yaml b/gitops/charts/traffic-court-test-values.yaml
index 6f5e9d9e5..1805d9bef 100644
--- a/gitops/charts/traffic-court-test-values.yaml
+++ b/gitops/charts/traffic-court-test-values.yaml
@@ -10,7 +10,7 @@ arc-dispute-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"Swagger__Enabled": "true"
@@ -20,7 +20,7 @@ citizen-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"FormRecognizer__ApiVersion": "2022-08-31"
@@ -39,7 +39,7 @@ citizen-web:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
route:
# https://test.justice.gov.bc.ca
@@ -48,7 +48,7 @@ citizen-web:
{
"production": false,
"environment": "Test",
- "version": "2.1.10",
+ "version": "2.2.9",
"useMockServices": false,
"apiBaseUrl": "/api",
"understandYourTicketLink": "https://bcmoag--staging.sandbox.my.salesforce-sites.com/?tn=BCTC",
@@ -205,7 +205,7 @@ oracle-data-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"JAVA_OPTS": ""
@@ -222,7 +222,7 @@ staff-api:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"Jwt__Audience": "staff-api"
@@ -240,7 +240,7 @@ staff-web:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
route:
# https://test.jag.gov.bc.ca
@@ -259,7 +259,7 @@ staff-web:
{
"production": false,
"environment": "Test",
- "version": "2.1.10",
+ "version": "2.2.9",
"useMockServices": false,
"apiBaseUrl": "/api",
"features": {
@@ -272,7 +272,7 @@ workflow-service:
pdb:
create: true
image:
- tag: "2.1.10"
+ tag: "2.2.9"
pullPolicy: Always
env:
"EmailConfiguration__Sender": "DoNotReply@gov.bc.ca"
From 612eac713f3c050b880c1a933b9e37266b82d9db Mon Sep 17 00:00:00 2001
From: Sai Krishna Metpalli <310911@NTTDATA.COM>
Date: Fri, 28 Jun 2024 13:06:13 -0700
Subject: [PATCH 02/13] TCVP-1617 fixed type field sorting
---
.../jj-dispute-wr-assignments.component.ts | 4 +++-
1 file changed, 3 insertions(+), 1 deletion(-)
diff --git a/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-wr-assignments/jj-dispute-wr-assignments.component.ts b/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-wr-assignments/jj-dispute-wr-assignments.component.ts
index 4fcaf0eea..5cb5053a5 100644
--- a/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-wr-assignments/jj-dispute-wr-assignments.component.ts
+++ b/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-wr-assignments/jj-dispute-wr-assignments.component.ts
@@ -71,7 +71,9 @@ export class JJDisputeWRAssignmentsComponent implements OnInit, AfterViewInit {
// custom sorting on columns
this.dataSource.sortingDataAccessor = (data: any, sortHeaderId: string): string => {
- if (typeof data[sortHeaderId] === 'string') {
+ if (sortHeaderId === 'timeToPayReason'){
+ return this.getType(data);
+ } else if (typeof data[sortHeaderId] === 'string') {
return data[sortHeaderId].toLocaleLowerCase();
}
return data[sortHeaderId];
From bdb08a1b22d18e27f4a97fc730be3702f8bd7c7f Mon Sep 17 00:00:00 2001
From: Sai Krishna Metpalli <310911@NTTDATA.COM>
Date: Tue, 2 Jul 2024 13:11:03 -0700
Subject: [PATCH 03/13] 2.2.10 updated the version
---
gitops/charts/traffic-court-dev-values.yaml | 18 +++++++++---------
gitops/charts/traffic-court-prod-values.yaml | 18 +++++++++---------
gitops/charts/traffic-court-test-values.yaml | 18 +++++++++---------
3 files changed, 27 insertions(+), 27 deletions(-)
diff --git a/gitops/charts/traffic-court-dev-values.yaml b/gitops/charts/traffic-court-dev-values.yaml
index e29ce6fbb..dbcd4a4cb 100644
--- a/gitops/charts/traffic-court-dev-values.yaml
+++ b/gitops/charts/traffic-court-dev-values.yaml
@@ -7,14 +7,14 @@ global:
arc-dispute-api:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"Swagger__Enabled": "true"
citizen-api:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"FormRecognizer__ApiVersion": "2022-08-31"
@@ -30,7 +30,7 @@ citizen-api:
citizen-web:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
route:
# https://dev.justice.gov.bc.ca
@@ -39,7 +39,7 @@ citizen-web:
{
"production": false,
"environment": "Dev",
- "version": "2.2.9",
+ "version": "2.2.10",
"useMockServices": false,
"apiBaseUrl": "/api",
"understandYourTicketLink": "https://understandmyticket.gov.bc.ca/",
@@ -193,7 +193,7 @@ citizen-web:
oracle-data-api:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"JAVA_OPTS": "-Dlogging.level.ca.bc.gov.open.jag.tco.oracledataapi=DEBUG"
@@ -208,7 +208,7 @@ oracle-data-api:
staff-api:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"Jwt__Audience": "staff-api"
@@ -222,7 +222,7 @@ staff-api:
staff-web:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
route:
# https://dev.jag.gov.bc.ca
@@ -241,7 +241,7 @@ staff-web:
{
"production": false,
"environment": "Dev",
- "version": "2.2.9",
+ "version": "2.2.10",
"useMockServices": false,
"apiBaseUrl": "/api",
"features": {
@@ -251,7 +251,7 @@ staff-web:
workflow-service:
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"EmailConfiguration__Sender": "DoNotReply@gov.bc.ca"
diff --git a/gitops/charts/traffic-court-prod-values.yaml b/gitops/charts/traffic-court-prod-values.yaml
index 3051369e0..d2068f6f2 100644
--- a/gitops/charts/traffic-court-prod-values.yaml
+++ b/gitops/charts/traffic-court-prod-values.yaml
@@ -10,7 +10,7 @@ arc-dispute-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"Swagger__Enabled": "false"
@@ -20,7 +20,7 @@ citizen-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"FormRecognizer__ApiVersion": "2022-08-31"
@@ -39,13 +39,13 @@ citizen-web:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
appConfig: |
{
"production": true,
"environment": "prod",
- "version": "2.2.9",
+ "version": "2.2.10",
"useMockServices": false,
"apiBaseUrl": "/api",
"understandYourTicketLink": "https://understandmyticket.gov.bc.ca/",
@@ -221,7 +221,7 @@ oracle-data-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"JAVA_OPTS": ""
@@ -238,7 +238,7 @@ staff-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"Jwt__Audience": "staff-api"
@@ -256,7 +256,7 @@ staff-web:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
route:
# https://test.jag.gov.bc.ca
@@ -275,7 +275,7 @@ staff-web:
{
"production": true,
"environment": "prod",
- "version": "2.2.9",
+ "version": "2.2.10",
"useMockServices": false,
"apiBaseUrl": "/api",
"features": {
@@ -288,7 +288,7 @@ workflow-service:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"EmailConfiguration__Sender": "DoNotReply@gov.bc.ca"
diff --git a/gitops/charts/traffic-court-test-values.yaml b/gitops/charts/traffic-court-test-values.yaml
index 1805d9bef..377c98e59 100644
--- a/gitops/charts/traffic-court-test-values.yaml
+++ b/gitops/charts/traffic-court-test-values.yaml
@@ -10,7 +10,7 @@ arc-dispute-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"Swagger__Enabled": "true"
@@ -20,7 +20,7 @@ citizen-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"FormRecognizer__ApiVersion": "2022-08-31"
@@ -39,7 +39,7 @@ citizen-web:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
route:
# https://test.justice.gov.bc.ca
@@ -48,7 +48,7 @@ citizen-web:
{
"production": false,
"environment": "Test",
- "version": "2.2.9",
+ "version": "2.2.10",
"useMockServices": false,
"apiBaseUrl": "/api",
"understandYourTicketLink": "https://bcmoag--staging.sandbox.my.salesforce-sites.com/?tn=BCTC",
@@ -205,7 +205,7 @@ oracle-data-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"JAVA_OPTS": ""
@@ -222,7 +222,7 @@ staff-api:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"Jwt__Audience": "staff-api"
@@ -240,7 +240,7 @@ staff-web:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
route:
# https://test.jag.gov.bc.ca
@@ -259,7 +259,7 @@ staff-web:
{
"production": false,
"environment": "Test",
- "version": "2.2.9",
+ "version": "2.2.10",
"useMockServices": false,
"apiBaseUrl": "/api",
"features": {
@@ -272,7 +272,7 @@ workflow-service:
pdb:
create: true
image:
- tag: "2.2.9"
+ tag: "2.2.10"
pullPolicy: Always
env:
"EmailConfiguration__Sender": "DoNotReply@gov.bc.ca"
From bb500bf233d2ee5e04f4da6a4b3cc4870604f6da Mon Sep 17 00:00:00 2001
From: Burak Karahan
- JJ endorsements: {{ element.comments }}
+ JJ Endorsements: {{ element.comments }}
Court Appearance
JJ endorsements:
+JJ Endorsements:
From c342108544ca2502e6a9a5a1b0cf5ebede5e2805 Mon Sep 17 00:00:00 2001
From: Sai Krishna Metpalli <310911@NTTDATA.COM>
Date: Mon, 8 Jul 2024 16:14:38 -0700
Subject: [PATCH 08/13] TCVP-3012 added arrow styling
---
.../jj-dispute-digital-case-file.component.scss | 4 ++++
1 file changed, 4 insertions(+)
diff --git a/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-digital-case-file/jj-dispute-digital-case-file.component.scss b/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-digital-case-file/jj-dispute-digital-case-file.component.scss
index e29d9dea0..547fb3ca8 100644
--- a/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-digital-case-file/jj-dispute-digital-case-file.component.scss
+++ b/src/frontend/staff-portal/src/app/components/jj-workbench/jj-dispute-digital-case-file/jj-dispute-digital-case-file.component.scss
@@ -70,4 +70,8 @@ th {
}
}
}
+
+ .mat-sort-header-arrow {
+ color: #757575;
+ }
}
\ No newline at end of file
diff --git a/src/frontend/staff-portal/src/app/components/jj-dispute-info/jj-dispute-remarks/jj-dispute-remarks.component.ts b/src/frontend/staff-portal/src/app/components/jj-dispute-info/jj-dispute-remarks/jj-dispute-remarks.component.ts
index 62f0b3a59..53eff6f7b 100644
--- a/src/frontend/staff-portal/src/app/components/jj-dispute-info/jj-dispute-remarks/jj-dispute-remarks.component.ts
+++ b/src/frontend/staff-portal/src/app/components/jj-dispute-info/jj-dispute-remarks/jj-dispute-remarks.component.ts
@@ -1,4 +1,4 @@
-import { Component, OnChanges, ViewChild, Input, OnDestroy } from '@angular/core';
+import { Component, ViewChild, Input, OnDestroy } from '@angular/core';
import { MatLegacyTableDataSource as MatTableDataSource } from '@angular/material/legacy-table';
import { MatSort } from '@angular/material/sort';
import { FileHistory, JJDisputeRemark } from 'app/api';
@@ -10,7 +10,7 @@ import { Subscription } from 'rxjs';
templateUrl: './jj-dispute-remarks.component.html',
styleUrls: ['./jj-dispute-remarks.component.scss'],
})
-export class JJDisputeRemarksComponent implements OnChanges, OnDestroy {
+export class JJDisputeRemarksComponent implements OnDestroy {
@Input() data: JJDisputeRemark[];
@ViewChild(MatSort) sort = new MatSort();
@@ -30,10 +30,6 @@ export class JJDisputeRemarksComponent implements OnChanges, OnDestroy {
}));
}
- ngOnChanges(): void {
- this.refreshData();
- }
-
ngOnDestroy(): void {
this.subscriptions.forEach(subscription => {
subscription.unsubscribe();
@@ -43,11 +39,13 @@ export class JJDisputeRemarksComponent implements OnChanges, OnDestroy {
refreshData(): void {
// Add ticket validation saving remarks
this.historyRecordService.FileHistories?.filter(i => i.auditLogEntryType === "FRMK").forEach((fileHistory: FileHistory) => {
- this.data.push( 4U}SA%bI~>1@SThM?)uB6 BYjz 8*~37w0nC!+hJ@Q%Qc1kio?jf91XgA}xInDurKb&{=`PCnJuK@vbKwQ4TSYKseViG$R
Mx#wC->I&~iX0-@E%#}tgC%@r|@^-+x63wtgQg!{y<2Ni}C
z4tt0xh=iNixdBn
T$r4c>tu
z$|_IR_E^>{^*YN$-{!Hgq{l%4Mfvq3(y2f_cO!8sZ3hjzO`ayo@dH3DYdfAQH%ki4
zeC;D-q`XTRya{W3g}HHHwmM-EZsXVzQ4tQWZES~*$Q2+4*5?>eWv<}tKA!D9I-l{b`X=&3C;j=+#BYv5gO`8V#W{X3(5{t!
z{F~V2C-)ynre2R?X%IxfNd@A$md{q`VW?X7Y;+ZacD*}&N?Y+m$F}aY%P({upkKF2
zW+v{cBj%X;UQQL(`3EV<@!XjowTU%u)YAlqGSWCm
|w3v6XmH!o-d`Wg=x87{O`C$|!hNMQX
z1<
cjUMWw^%H;o3TImmyf#de+VvQchpTNa8H;A~PH2q`jjx6z?3
zG9tLl{1%QVag`wL;Eo|0DAuvwcDM!OW1n%KwvrIeleHlVh3kVb8+xtHXlImELHI_D
z@qfpiBr(QMO0+?qpW&oHI$R0d$oIBtfdiiwYv`X)U*kaY=fU&Bf>k|^0u@nfL0qO*
ze>+pBbH*-vF@qzx+n1wXb$1txF{q)cP7|{6vJtDzC;{tauYx?$Uo1CSe9%Q4WUl-j
zZPZ{n@IA+1{N=K<>iJxjH=8t
From 8e3a67289a153c527352ab29a1aad3887c7b9a4d Mon Sep 17 00:00:00 2001
From: Sai Krishna Metpalli <310911@NTTDATA.COM>
Date: Tue, 9 Jul 2024 11:29:27 -0700
Subject: [PATCH 09/13] TCVP-2589 added file remark history for reject and
cancel
---
.../Staff.Service/Services/DisputeService.cs | 22 ++++++++++++++-----
.../jj-dispute-remarks.component.ts | 22 +++++++++----------
2 files changed, 27 insertions(+), 17 deletions(-)
diff --git a/src/backend/TrafficCourts/Staff.Service/Services/DisputeService.cs b/src/backend/TrafficCourts/Staff.Service/Services/DisputeService.cs
index 189d607f4..3fb711a0d 100644
--- a/src/backend/TrafficCourts/Staff.Service/Services/DisputeService.cs
+++ b/src/backend/TrafficCourts/Staff.Service/Services/DisputeService.cs
@@ -280,13 +280,17 @@ public async Task CancelDisputeAsync(long disputeId, string cancelledReason, Cla
GetUserName(user));
await _bus.PublishWithLog(_logger, fileHistoryRecord, cancellationToken);
- // Publish file history of cancellation email
- fileHistoryRecord.AuditLogEntryType = FileHistoryAuditLogEntryType.EMCA;
- await _bus.PublishWithLog(_logger, fileHistoryRecord, cancellationToken);
+ // Publish file history for cancelled remarks
+ SaveFileHistoryRecord fileHistoryRecordRemark = Mapper.ToFileHistoryWithNoticeOfDisputeId(
+ dispute.NoticeOfDisputeGuid,
+ FileHistoryAuditLogEntryType.FRMK,
+ GetUserName(user),
+ cancelledReason);
+ await _bus.PublishWithLog(_logger, fileHistoryRecordRemark, cancellationToken);
// Publish cancel event (consumer(s) will generate email, etc)
DisputeCancelled cancelledEvent = Mapper.ToDisputeCancelled(dispute);
- await _bus. PublishWithLog(_logger, cancelledEvent, cancellationToken);
+ await _bus.PublishWithLog(_logger, cancelledEvent, cancellationToken);
}
public async Task RejectDisputeAsync(long disputeId, string rejectedReason, ClaimsPrincipal user, CancellationToken cancellationToken)
@@ -304,7 +308,15 @@ public async Task RejectDisputeAsync(long disputeId, string rejectedReason, Clai
GetUserName(user));
await _bus.PublishWithLog(_logger, fileHistoryRecord, cancellationToken);
- // Publish submit event (consumer(s) will generate email, etc)
+ // Publish file history for rejected remarks
+ SaveFileHistoryRecord fileHistoryRecordRemark = Mapper.ToFileHistoryWithNoticeOfDisputeId(
+ dispute.NoticeOfDisputeGuid,
+ FileHistoryAuditLogEntryType.FRMK,
+ GetUserName(user),
+ rejectedReason);
+ await _bus.PublishWithLog(_logger, fileHistoryRecordRemark, cancellationToken);
+
+ // Publish reject event (consumer(s) will generate email, etc)
DisputeRejected rejectedEvent = Mapper.ToDisputeRejected(dispute);
await _bus.PublishWithLog(_logger, rejectedEvent, cancellationToken);
}